===========================
Machine Learning Algorithms
===========================


.. image:: https://img.shields.io/pypi/v/MLStudio.svg
        :target: https://pypi.python.org/pypi/MLStudio

.. image:: https://readthedocs.org/projects/MLStudio/badge/?version=latest
        :target: https://MLStudio.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/decisionscients/MLStudio/shield.svg
     :target: https://pyup.io/repos/github/decisionscients/MLStudio/
     :alt: Updates



Machine Learning Algorithms


* Free software: BSD license
* Documentation: https://MLStudio.readthedocs.io.


Features
--------

* TODO

Credits
-------
